document.addEventListener('DOMContentLoaded', () => {
  const pathQuiz = document.getElementById('pathQuiz');
  const result = document.getElementById('result');

  pathQuiz.addEventListener('submit', (e) => {
    e.preventDefault();
    
    const formData = new FormData(pathQuiz);
    const technical = parseInt(formData.get('technical'));
    const peace = parseInt(formData.get('peace'));
    const preference = formData.get('preference');
    
    let engineeringScore = calculateEngineeringScore(technical, peace, preference);
    let spiritualityScore = calculateSpiritualityScore(technical, peace, preference);
    
    displayResult(engineeringScore, spiritualityScore);
  });

  function calculateEngineeringScore(technical, peace, preference) {
    let score = technical * 1.5;
    if (preference === 'machines') score += 20;
    if (preference === 'both') score += 10;
    return score;
  }

  function calculateSpiritualityScore(technical, peace, preference) {
    let score = peace * 1.5;
    if (preference === 'people') score += 20;
    if (preference === 'both') score += 10;
    return score;
  }

  function displayResult(engineeringScore, spiritualityScore) {
    result.style.display = 'block';
    
    let recommendation = '';
    if (engineeringScore > spiritualityScore) {
      recommendation = `Based on your responses, you show a stronger inclination towards engineering (${engineeringScore.toFixed(1)}%) compared to spirituality (${spiritualityScore.toFixed(1)}%).`;
    } else if (spiritualityScore > engineeringScore) {
      recommendation = `Your responses indicate a stronger connection with spirituality (${spiritualityScore.toFixed(1)}%) compared to engineering (${engineeringScore.toFixed(1)}%).`;
    } else {
      recommendation = 'Your responses show equal interest in both paths. Consider exploring both options further.';
    }
    
    result.innerHTML = `
      <h3>Your Path Analysis</h3>
      <p>${recommendation}</p>
      <p class="note">Remember: This is just a guide. The final decision should align with your personal values and goals.</p>
    `;
    
    result.scrollIntoView({ behavior: 'smooth' });
  }

  // Smooth scrolling for navigation links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      document.querySelector(this.getAttribute('href')).scrollIntoView({
        behavior: 'smooth'
      });
    });
  });
});
